@@ -14,6 +14,7 @@
 #include "Component.h"
 #include "InputEvent.h"
 #include "TextSurface.h"
+#include "TextProperty.h"
 #include "TtfResource.h"
 
 using namespace beego;
@@ -30,16 +31,19 @@ struct ButtonComponent::pImpl {
   SDL_Rect position;
   bool position_changed;
   bool is_decided;
+  bool is_changed;
   DrawSurface draw_surface;
 
-  pImpl(void)
-    : surface(new SwitchSurface), position_changed(true), is_decided(false) {
+  pImpl(void) :
+    surface(new SwitchSurface), position_changed(false), is_decided(false),
+    is_changed(false) {
+
     set_SdlRect(&position, 0, 0, 0, 0);
   }
 
   void updateComponentSize(void) {
-    position.w = surface->getWidth();
-    position.h = surface->getHeight();
+    position.w = static_cast<int>(surface->getWidth());
+    position.h = static_cast<int>(surface->getHeight());
   }
 };
 
@@ -53,9 +57,9 @@ ButtonComponent::~ButtonComponent(void) {
 
 
 void ButtonComponent::addSurfaceList(SurfaceList& surfaces,
-				     const SDL_Rect* area, size_t ticks) {
+                                     const SDL_Rect* area, size_t ticks) {
   updateDrawSurface(pimpl->draw_surface, pimpl->surface, area,
-		    pimpl->position, pimpl->position_changed);
+                    pimpl->position, pimpl->position_changed);
   surfaces.push_back(&pimpl->draw_surface);
   pimpl->position_changed = false;
 }
@@ -84,9 +88,9 @@ size_t ButtonComponent::getHeight(void) {
 
 
 void ButtonComponent::registerNormalSurface(Surface surface,
-					    int x_offset, int y_offset) {
+                                            int x_offset, int y_offset) {
   pimpl->surface->registerSurface(surface, x_offset, y_offset,
-				  pImpl::NormalSurface);
+                                  pImpl::NormalSurface);
   // ʏ{^́Ao^ꂽftHgŕ\悤ɐݒ肷
   showNormalSurface();
   pimpl->updateComponentSize();
@@ -94,30 +98,36 @@ void ButtonComponent::registerNormalSurface(Surface surface,
 
 
 void ButtonComponent::registerPressedSurface(Surface surface,
-					     int x_offset, int y_offset) {
+                                             int x_offset, int y_offset) {
   pimpl->surface->registerSurface(surface, x_offset, y_offset,
-				  pImpl::PressedSurface);
+                                  pImpl::PressedSurface);
 
   // T[tFX傫o^̂߂ɁAꎞIɃT[tFX؂ւ
-  size_t now_index = pimpl->surface->getIndex();
+  size_t now_index = pimpl->surface->getSurfaceIndex();
   pimpl->updateComponentSize();
   pimpl->surface->switchSurface(now_index);
 }
 
 
 void ButtonComponent::registerFocusedSurface(Surface surface,
-					     int x_offset, int y_offset) {
+                                             int x_offset, int y_offset) {
   pimpl->surface->registerSurface(surface, x_offset, y_offset,
-				  pImpl::FocusedSurface);
+                                  pImpl::FocusedSurface);
 
   // T[tFX傫o^̂߂ɁAꎞIɃT[tFX؂ւ
-  size_t now_index = pimpl->surface->getIndex();
+  size_t now_index = pimpl->surface->getSurfaceIndex();
   pimpl->updateComponentSize();
   pimpl->surface->switchSurface(now_index);
 }
 
 
-void ButtonComponent::applyInput(const InputEvent& event) {
+Surface ButtonComponent::getNormalSurface(void) {
+  return pimpl->surface->getSurface(pImpl::NormalSurface);
+}
+
+
+void ButtonComponent::applyInput(const InputEvent& event,
+                                 std::vector<SDL_Rect>& applied_rects) {
 
   if (pimpl->is_decided) {
     // ɉԂȂ΁AԂXVȂ
@@ -126,7 +136,7 @@ void ButtonComponent::applyInput(const InputEvent& event) {
 
   SDL_Rect surface_area;
   set_SdlRect(&surface_area, pimpl->position.x, pimpl->position.y,
-	      getWidth(), getHeight());
+              static_cast<int>(getWidth()), static_cast<int>(getHeight()));
 
   // }EXA\T[tFXɂꍇ̏
   bool changed = false;
@@ -141,6 +151,7 @@ void ButtonComponent::applyInput(const InputEvent& event) {
       // 肳ꂽ
       showPressedSurface();
       pimpl->is_decided = true;
+      pimpl->is_changed = true;
 
     } else {
       // tH[JX
@@ -174,58 +185,44 @@ void ButtonComponent::showFocusedSurface(void) {
 }
 
 
+bool ButtonComponent::isChanged(void) {
+  bool ret = pimpl->is_changed;
+  pimpl->is_changed = false;
+  return ret;
+}
+
+
 bool ButtonComponent::isDecided(void) {
   return pimpl->is_decided;
 }
 
 
+void ButtonComponent::setDecided(void) {
+  pimpl->is_decided = true;
+  pimpl->is_changed = true;
+  showPressedSurface();
+}
+
+
 void ButtonComponent::releaseDecided(void) {
   pimpl->is_decided = false;
 }
 
 
-void ButtonComponent::createSimpleButton(boost::shared_ptr<ButtonComponent>&
-					 button, TtfResource* font,
-					 const Uint16* text, size_t size,
-					 Uint32 fore, Uint32 back,
-					 size_t selected_size,
-					 Uint32 selected_fore,
-					 Uint32 selected_back,
-					 bool transparent) {
+void ButtonComponent::createButton(boost::shared_ptr<ButtonComponent>& button,
+                                   const TextProperty& normal_property,
+                                   const TextProperty& selected_property,
+                                   const TextProperty& pressed_property) {
+
   // ʏT[tFX̍쐬
-  Surface normal(new TextSurface(font, text, size, fore, back, transparent));
+  Surface normal(new TextSurface(normal_property));
   button->registerNormalSurface(normal);
 
   // IT[tFX̍쐬
-  Surface focused(new TextSurface(font, text, selected_size,
-				  selected_fore, selected_back, transparent));
+  Surface focused(new TextSurface(selected_property));
   button->registerFocusedSurface(focused);
 
   // 莞T[tFX̍쐬
-  button->registerPressedSurface(focused);
-}
-
-
-void ButtonComponent::createSimpleButton(boost::shared_ptr<ButtonComponent>&
-					 button, TtfResource* font,
-					 const char* text, size_t size,
-					 Uint32 fore, Uint32 back,
-					 size_t selected_size,
-					 Uint32 selected_fore,
-					 Uint32 selected_back,
-					 bool transparent) {
-  // !!! ̏d́A...
-  // !!! ȂƂ܂傤Bev[gɂłȂ񂾂...
-
-  // ʏT[tFX̍쐬
-  Surface normal(new TextSurface(font, text, size, fore, back, transparent));
-  button->registerNormalSurface(normal);
-
-  // IT[tFX̍쐬
-  Surface focused(new TextSurface(font, text, selected_size,
-				  selected_fore, selected_back, transparent));
-  button->registerFocusedSurface(focused);
-
-  // 莞T[tFX̍쐬
-  button->registerPressedSurface(focused);
+  Surface pressed(new TextSurface(pressed_property));
+  button->registerPressedSurface(pressed);
 }
