@@ -26,11 +26,11 @@ namespace beego {
     const std::auto_ptr<pImpl> pimpl;
 
   public:
-    explicit ColorSurface(Uint32 color, size_t width, size_t height);
+    explicit ColorSurface(size_t width, size_t height, Uint32 color);
     ~ColorSurface(void);
 
     void draw(std::vector<SDL_Rect>& update_rects,
-	      const SDL_Rect* pos, const SDL_Rect* area, size_t ticks);
+              const SDL_Rect* pos, const SDL_Rect* area, size_t ticks);
     size_t getWidth(void);
     size_t getHeight(void);
     void forceSetChanged(void);
