@@ -6,6 +6,7 @@
 
   $Id$
 
+  \todo ComponentUtils Ȃǂɉׂ
   \todo addDrawSurface() ȂǂÃt@CɈړAH
 */
 
@@ -13,18 +14,25 @@
 #include "ComponentInterface.h"
 #include "SurfaceInterface.h"
 #include "SdlUtils.h"
+#include "EvaluateArea.h"
 
 
 // !!! area, position œnႤ̂C
 void beego::updateDrawSurface(DrawSurface& draw_surface, Surface surface,
-			      const SDL_Rect* area, const SDL_Rect& position,
-			      bool position_changed) {
+                              const SDL_Rect* area,
+                              const SDL_Rect& position,
+                              bool position_changed) {
 
   // !!! EvaluateArea łĒuAȁH
 
   // R|[lg̈ area ̋ʕ component_area ƂȂ
-  draw_surface.mustDraw = true;
   draw_surface.surface = surface;
+  if (! area) {
+    // surface oړÎƂ́AŖ߂
+    return;
+  }
+
+  draw_surface.mustDraw = true;
   draw_surface.position = position;
   draw_surface.position_changed = position_changed;
   draw_surface.is_changed = surface->isChanged();
@@ -54,6 +62,25 @@ void beego::updateDrawSurface(DrawSurface& draw_surface, Surface surface,
 
   // `̈悪ȂȂAmustDraw  false ɂ
   // !!!
+  // !!! ƂL̋LqAłӖ̂s
+  // !!! CčČ
+}
+
+
+extern bool beego::isAppliedRect(const int x, const int y,
+                                 const std::vector<SDL_Rect>& applied_rects) {
+
+  for (std::vector<SDL_Rect>::const_iterator it = applied_rects.begin();
+       it != applied_rects.end(); ++it) {
+
+    // _̈ʒu͔ɗpς݂ false Ԃ
+    if (isPointInside(x, y, *it)) {
+      return false;
+    }
+  }
+
+  // ǂ̗̈łgĂȂ΁Atrue Ԃ
+  return true;
 }
 
 
@@ -63,12 +90,12 @@ int beego::leftPosition(Component component, int left_position) {
 
 
 int beego::centerPosition(Component component, int center_position) {
-  return center_position - component->getWidth()/2;
+  return center_position - static_cast<int>(component->getWidth()/2);
 }
 
 
 int beego::rightPosition(Component component, int right_position) {
-  return right_position - component->getWidth();
+  return right_position - static_cast<int>(component->getWidth());
 }
 
 
@@ -78,10 +105,10 @@ int beego::topPosition(Component component, int top_position) {
 
 
 int beego::middlePosition(Component component, int middle_position) {
-  return middle_position - component->getHeight()/2;
+  return middle_position - static_cast<int>(component->getHeight()/2);
 }
 
 
 int beego::bottomPosition(Component component, int bottom_position) {
-  return bottom_position - component->getHeight();
+  return bottom_position - static_cast<int>(component->getHeight());
 }
