@@ -21,9 +21,15 @@ namespace beego {
   typedef boost::shared_ptr<ComponentInterface> Component;
 
   extern void updateDrawSurface(DrawSurface& draw_surface,
-				Surface surface, const SDL_Rect* area,
-				const SDL_Rect& position,
-				bool position_changed);
+                                Surface surface, const SDL_Rect* area,
+                                const SDL_Rect& position,
+                                bool position_changed);
+
+  /*!
+    \brief _̈ʒu͔ɗpς݂A𔻒
+  */
+  extern bool isAppliedRect(const int x, const int y,
+                            const std::vector<SDL_Rect>& applied_rects);
 
   extern int leftPosition(Component component, int left_position);
   extern int centerPosition(Component component, int center_position);
