@@ -10,7 +10,8 @@
 #include "CreateSurfaceFromArray.h"
 
 
-SDL_Surface* beego::createSurface(const char data[], int width, int height) {
+SDL_Surface* beego::createSurface(const unsigned char data[],
+                                  int width, int height) {
 
 #if SDL_BYTEORDER == SDL_BIG_ENDIAN
   Uint32 rmask = 0xff000000;
@@ -24,7 +25,7 @@ SDL_Surface* beego::createSurface(const char data[], int width, int height) {
   Uint32 amask = 0xff000000;
 #endif
 
-  return SDL_CreateRGBSurfaceFrom(const_cast<char*>(data),
-				  width, height, 32, width * 4,
-				  rmask, gmask, bmask, amask);
+  return SDL_CreateRGBSurfaceFrom(const_cast<unsigned char*>(data),
+                                  width, height, 32, width * 4,
+                                  rmask, gmask, bmask, amask);
 }
