@@ -27,12 +27,14 @@ namespace beego {
 
     class InputKey {
     public:
-      SDLKey sym;
-      SDLMod mod;
-      Uint16 unicode;
+      SDLKey sym_;
+      SDLMod mod_;
+      Uint16 unicode_;
+      bool pressed_;
 
-      InputKey(SDLKey sym_value, SDLMod mod_value, Uint16 unicode_value)
-	: sym(sym_value), mod(mod_value), unicode(unicode_value) {
+      InputKey(SDLKey sym, SDLMod mod, Uint16 unicode, bool pressed)
+        : sym_(sym), mod_(mod), unicode_(unicode),
+	  pressed_(pressed) {
       }
     };
     typedef std::vector<InputKey> InputKeys;
@@ -42,7 +44,7 @@ namespace beego {
 
     InputEvent(void)
       : mx(0), my(0), mouse_moved(false), wheels(0),
-	left_clicked(false), left_released(false) {
+        left_clicked(false), left_released(false) {
     }
 
     static bool isPressed(const InputEvent& event, SDLKey key);
