@@ -17,7 +17,6 @@ namespace beego {
   class Layer;
   class InputEvent;
 
-
   /*!
     \brief `惌C[Ǘ
   */
@@ -33,16 +32,18 @@ namespace beego {
     LayerManager(SurfaceList& surface_list);
     ~LayerManager(void);
 
-    void applyInput(ComponentList& components, const InputEvent& event);
+    void updateScreenSurface(SDL_Surface* scr);
+    void applyInput(ComponentList& components, const InputEvent& event,
+                    std::vector<SDL_Rect>& applied_rects);
     void redraw(std::vector<SDL_Rect>& update_rects,
-		SurfaceList& surfaces, size_t ticks);
+                SurfaceList& surfaces, size_t ticks);
     void push_front(Layer* layer);
     void push_back(Layer* layer);
     void insert(const Layer* dst, Layer* layer);
     void remove(Layer* layer);
     void createComponentList(ComponentList& components);
     void createSurfaceList(SurfaceList& surfaces,
-			   const ComponentList& components, size_t ticks);
+                           const ComponentList& components, size_t ticks);
     void removeSurface(SurfaceList& remove_list);
   };
 };
