@@ -5,6 +5,9 @@
   \author Satofumi KAMIMURA
 
   $Id$
+
+  \todo ڂ̊ԊuCӂ̊Ԋuɐݒł悤ɂ
+  \todo c^zuA^zuw肷΁AŃItZbg悤ɂ
 */
 
 #include "MenuComponent.h"
@@ -13,11 +16,15 @@
 #include "SdlUtils.h"
 #include "Component.h"
 #include "InputEvent.h"
+#include "EvaluateArea.h"
 
 using namespace beego;
 
 
 struct MenuComponent::pImpl {
+  enum {
+    SurfaceWidth = 0,
+  };
   size_t width;
   size_t height;
   int selected_index;
@@ -30,7 +37,7 @@ struct MenuComponent::pImpl {
     SDL_Rect position;
 
     MenuItem(boost::shared_ptr<ButtonComponent> button_obj,
-	     int x_offset, int y_offset)
+             int x_offset, int y_offset)
       : button(button_obj), offset(Grid<int>(x_offset, y_offset)) {
       set_SdlRect(&position, 0, 0);
     }
@@ -38,10 +45,12 @@ struct MenuComponent::pImpl {
   std::vector<MenuItem> items;
   SDL_Rect position;
   bool position_changed;
+  bool key_changed;
+  size_t select_width;
 
   pImpl(void)
     : width(0), height(0), selected_index(NoSelect), decided_index(NoSelect),
-      position_changed(true) {
+      position_changed(false), key_changed(false), select_width(SurfaceWidth) {
     set_SdlRect(&position, 0, 0, 0, 0);
   }
 
@@ -50,19 +59,19 @@ struct MenuComponent::pImpl {
     size_t max_width = 0, max_height = 0;
     int x = 0, y = 0;
     for (std::vector<MenuItem>::iterator it = items.begin();
-	 it != items.end(); ++it) {
-
-      int w = x + it->button->getWidth();
+         it != items.end(); ++it) {
+      size_t button_width = it->button->getWidth();
+      int w = x + button_width;
       if (w > static_cast<int>(max_width)) {
-	max_width = w;
+        max_width = w;
       }
 
-      int h = y + it->button->getHeight();
+      size_t button_height = it->button->getHeight();
+      int h = y + button_height;
       if (h > static_cast<int>(max_height)) {
-	max_height = h;
+        max_height = h;
       }
-      it->position.x = x;
-      it->position.y = y;
+      set_SdlRect(&it->position, x, y, button_width, button_height);
 
       x += it->offset.x;
       y += it->offset.y;
@@ -72,6 +81,29 @@ struct MenuComponent::pImpl {
     position.w = max_width;
     position.h = max_height;
   }
+
+  void surfaceUpdate(void) {
+
+    // !!! Ƃ肠Ad͋Cɂ쐬
+    int index = 0;
+    for (std::vector<MenuItem>::iterator it = items.begin();
+         it != items.end(); ++it, ++index) {
+      boost::shared_ptr<ButtonComponent>& p = it->button;
+
+      if (index == decided_index) {
+        // Ăꍇ
+        p->showPressedSurface();
+
+      } else if (index == selected_index) {
+        // IT[tFX
+        p->showFocusedSurface();
+
+      } else {
+        // ʏT[tFX
+        p->showNormalSurface();
+      }
+    }
+  }
 };
 
 
@@ -84,7 +116,7 @@ MenuComponent::~MenuComponent(void) {
 
 
 void MenuComponent::addSurfaceList(SurfaceList& surfaces,
-				   const SDL_Rect* area, size_t ticks) {
+                                   const SDL_Rect* area, size_t ticks) {
   if (pimpl->items.empty()) {
     return;
   }
@@ -97,7 +129,7 @@ void MenuComponent::addSurfaceList(SurfaceList& surfaces,
 
     SDL_Rect position;
     set_SdlRect(&position, pimpl->position.x + x, pimpl->position.y + y,
-		p->getWidth(), p->getHeight());
+                p->getWidth(), p->getHeight());
     // !!! ŁAposition_changed  true ɂȂ̂ŁAĕ`悳
     // !!! setPosition ̂́A
     // !!! EsetItemsOffset() ݂̂ł悢͂
@@ -115,11 +147,11 @@ void MenuComponent::addSurfaceList(SurfaceList& surfaces,
 
     } else {
       if (index == pimpl->decided_index) {
-	// Ăꍇ
-	p->showPressedSurface();
+        // Ăꍇ
+        p->showPressedSurface();
       } else {
-	// IT[tFX
-	p->showFocusedSurface();
+        // IT[tFX
+        p->showFocusedSurface();
       }
     }
 
@@ -132,7 +164,7 @@ void MenuComponent::addSurfaceList(SurfaceList& surfaces,
 
 void MenuComponent::setPosition(const SDL_Rect* position) {
   set_SdlRect(&pimpl->position, position->x, position->y,
-	      pimpl->position.w, pimpl->position.h);
+              pimpl->position.w, pimpl->position.h);
   pimpl->updateComponentSize();
   pimpl->position_changed = true;
 }
@@ -153,7 +185,8 @@ size_t MenuComponent::getHeight(void) {
 }
 
 
-void MenuComponent::applyInput(const InputEvent& event) {
+void MenuComponent::applyInput(const InputEvent& event,
+                               std::vector<SDL_Rect>& applied_rects) {
 
   if (pimpl->decided_index != NoSelect) {
     // ɉԂȂ΁AԂXVȂ
@@ -163,32 +196,34 @@ void MenuComponent::applyInput(const InputEvent& event) {
   // }EXʒuɂ鍀ڂIɂ
   int index = 0;
   int x = 0, y = 0;
-  if (event.mouse_moved) {
+  if (event.mouse_moved || (! pimpl->key_changed)) {
+    pimpl->key_changed = false;
     for (std::vector<pImpl::MenuItem>::iterator it = pimpl->items.begin();
-	 it != pimpl->items.end(); ++it) {
+         it != pimpl->items.end(); ++it) {
       boost::shared_ptr<ButtonComponent>& p = it->button;
 
       // !!! button  applyInput KpH
       // !!! ButtonComponent AČ
 
       SDL_Rect surface_area;
+      size_t width = (pimpl->select_width == pImpl::SurfaceWidth)
+        ? p->getWidth() : pimpl->select_width;
       set_SdlRect(&surface_area, pimpl->position.x + x, pimpl->position.y + y,
-		  p->getWidth(), p->getHeight());
+                  width, p->getHeight());
 
       // }EXA\T[tFXɂꍇ̏
       // !!! ۂɂ͕`悳ĂȂꍇ肤邪AƂ肠CɂȂ
-      if (((event.mx >= surface_area.x) &&
-	   (event.mx <= surface_area.x + surface_area.w)) &&
-	  ((event.my >= surface_area.y) &&
-	   (event.my <= surface_area.y + surface_area.h))) {
-	// Iꂽ
-	pimpl->selected_index = index;
+      // !!! R|[lg`͈͊ȌꍇƂABĂꍇ
+      bool cursor_inside = isPointInside(event.mx, event.my, surface_area);
+      if (cursor_inside) {
+        // Iꂽ
+        pimpl->selected_index = index;
 
-	if (event.left_released) {
-	  // 肳ꂽ
-	  pimpl->decided_index = index;
-	}
-	break;
+        if (event.left_released) {
+          // 肳ꂽ
+          pimpl->decided_index = index;
+        }
+        break;
       }
 
       x += it->offset.x;
@@ -205,18 +240,22 @@ void MenuComponent::applyInput(const InputEvent& event) {
     if ((pimpl->selected_index > 0) && (*it == SDLK_UP)) {
       // 
       --pimpl->selected_index;
+      pimpl->key_changed = true;
 
     } else if ((pimpl->selected_index < max) &&  (*it == SDLK_DOWN)) {
       // 
       ++pimpl->selected_index;
+      pimpl->key_changed = true;
 
     } else if (*it == SDLK_LEFT) {
       // ňԏ
       pimpl->selected_index = 0;
+      pimpl->key_changed = true;
 
     } else if (*it == SDLK_RIGHT) {
       // Eňԉ
       pimpl->selected_index = max;
+      pimpl->key_changed = true;
 
     } else if (*it == SDLK_RETURN) {
       // ^[L[Ō
@@ -238,7 +277,7 @@ void MenuComponent::clearItems(void) {
 
 
 void MenuComponent::addItem(boost::shared_ptr<ButtonComponent> item,
-			    int x_offset, int y_offset) {
+                            int x_offset, int y_offset) {
 
   // {^̒ǉ
   pimpl->items.push_back(pImpl::MenuItem(item, x_offset, y_offset));
@@ -267,15 +306,51 @@ void MenuComponent::setItemsOffset(int x_offset, int y_offset) {
 }
 
 
+void MenuComponent::getItemPosition(SDL_Rect* offset, size_t index) {
+  *offset = pimpl->items[index].position;
+}
+
+
+void MenuComponent::adjustItemsVerticalOffset(size_t additional_offset) {
+
+  for (std::vector<pImpl::MenuItem>::iterator it = pimpl->items.begin();
+       it != pimpl->items.end(); ++it) {
+    it->offset.y = it->button->getHeight() + additional_offset;
+  }
+
+  // width, height ̍ČvZ
+  pimpl->updateComponentSize();
+  pimpl->position_changed = true;
+}
+
+
+void MenuComponent::adjustItemsHorizontalOffset(size_t additional_offset) {
+
+  for (std::vector<pImpl::MenuItem>::iterator it = pimpl->items.begin();
+       it != pimpl->items.end(); ++it) {
+    it->offset.x = it->button->getWidth() + additional_offset;
+  }
+
+  // width, height ̍ČvZ
+  pimpl->updateComponentSize();
+  pimpl->position_changed = true;
+}
+
+
 void MenuComponent::setSelected(int index) {
   // !!! bN
+  releaseDecided();
   pimpl->selected_index = index;
+  pimpl->surfaceUpdate();
 }
 
 
 void MenuComponent::setDecided(int index) {
   // !!! bN
+  releaseDecided();
+  pimpl->selected_index = index;
   pimpl->decided_index = index;
+  pimpl->surfaceUpdate();
 }
 
 
@@ -299,3 +374,8 @@ void MenuComponent::releaseDecided(void) {
   pimpl->selected_index = pimpl->decided_index;
   pimpl->decided_index = NoSelect;
 }
+
+
+void MenuComponent::setItemSelectWidth(size_t width) {
+  pimpl->select_width = width;
+}
