@@ -29,6 +29,11 @@ namespace beego {
     ~MixerInit(void);
 
     bool isInitialized(void);
+
+  public:
+    enum {
+      ChannelNum = 8,
+    };
   };
 };
 
