@@ -8,9 +8,6 @@
 
   \todo ڂ̐̓|bvAbvōs
   \todo KAnCXRAo^̋Ad_KA̍ڂzu
-  \todo [U쐬Ao^̍ڂzu
-  \todo [Uo^̎dg݂Ď
-  \todo OCA[U쐬̃ftHgƂ
   \todo ̓[h̍XVs
 */
 
