@@ -19,11 +19,12 @@
 #include "Layer.h"
 #include "InputHandler.h"
 #include "TextSurface.h"
+#include "TextProperty.h"
 #include "LabelComponent.h"
 #include "MenuComponent.h"
 #include "ButtonComponent.h"
 #include "MusicManager.h"
-#include "LockGuard.h"
+#include "SoundEffectManager.h"
 #include "SdlUtils.h"
 #include "Delay.h"
 
@@ -32,37 +33,46 @@ using namespace beego;
 
 struct PracticeMenu::pImpl {
   CommonResources* common;
-  SDL_mutex* mutex;
   TtfResource* font;
+  TextProperty title_property;
   Surface title_surface;
   Component title_label;
   boost::shared_ptr<MenuComponent> menu;
 
   pImpl(void)
-    : common(CommonResources::getObject()), mutex(common->gui->getMutex()),
+    : common(CommonResources::getObject()),
       font(common->font),
-      title_surface(new TextSurface(font, PracticeMenu_title, TitleSize,
-				    Fore, Back, true)),
+      title_property(font, PracticeMenu_title, TitleSize,
+                     Fore, Back, true),
+      title_surface(new TextSurface(title_property)),
       title_label(new LabelComponent(title_surface)), menu(new MenuComponent) {
 
     SDL_Rect position;
     // !!! 640, 480 ܂̒萔͒u
     set_SdlRect(&position, centerPosition(title_label, 640/2),
-		middlePosition(title_label, 480/4));
+                middlePosition(title_label, 480/4));
     title_label->setPosition(&position);
 
     // j[̍ڂ쐬
     const Uint16 *titles[] = {
       PracticeMenu_shimonoku, PracticeMenu_kimariji, PracticeMenu_back,
     };
+
+    size_t max_width = 0;
     for (size_t i = 0; i < sizeof(titles)/sizeof(titles[0]); ++i) {
       boost::shared_ptr<ButtonComponent> new_button(new ButtonComponent);
-      ButtonComponent::createSimpleButton(new_button, common->font,
-					  titles[i], MenuSize, Fore, Back,
-					  MenuSize, Blue, Back, true);
+      TextProperty normal(common->font, titles[i], MenuSize,
+                          Fore, Back, true);
+      TextProperty selected(common->font, titles[i], MenuSize,
+                            Selected, Back, true);
+      ButtonComponent::createButton(new_button, normal, selected, selected);
+      if (new_button->getWidth() > max_width) {
+        max_width = new_button->getWidth();
+      }
       menu->addItem(new_button);
     }
     menu->setItemsOffset(0, MenuSize + 16);
+    menu->setItemSelectWidth(max_width);
     menu->setSelected(0);
 
     set_SdlRect(&position, centerPosition(menu, 640/2), 480/4 + MenuOffset);
@@ -71,13 +81,11 @@ struct PracticeMenu::pImpl {
   }
 
   void placeComponents(void) {
-    LockGuard guard(mutex);
     common->front_layer->push_front(title_label);
     common->front_layer->push_front(menu);
   }
 
   void removeComponents(void) {
-    LockGuard guard(mutex);
     common->front_layer->remove(title_label);
     common->front_layer->remove(menu);
   }
@@ -109,41 +117,48 @@ PracticeMenu::~PracticeMenu(void) {
 
 void PracticeMenu::run(void) {
 
+  GuiManager* gui = pimpl->common->gui;
   InputHandler& input = *pimpl->common->input;
   bool quit = false;
   while (quit == false) {
 
     int selected = pimpl->menu->getDecided();
     if (selected >= 0) {
-      pimpl->removeComponents();
 
+      // !!! Ƃ肠AŌ艹炷
+      // !!! Is\ȍڂ肵ƂɉςȂAύX
+      if (pimpl->common->music) {
+        pimpl->common->sound_effect->play(Decide);
+      }
+
+      pimpl->removeComponents();
       if (selected == 0) {
-	// ̋^CsO
-	pimpl->stopMusic();
-	ShimonokuPractice shimonoku_practice;
-	shimonoku_practice.run();
-	pimpl->playMusic();
+        // ̋^CsO
+        pimpl->stopMusic();
+        ShimonokuPractice shimonoku_practice;
+        shimonoku_practice.run();
+        pimpl->playMusic();
 
       } else if (selected == 1) {
-	// ܂莚^CsO
-	pimpl->stopMusic();
+        // ܂莚^CsO
+        pimpl->stopMusic();
 
-	KimarijiPractice kimariji_practice;
-	kimariji_practice.run();
-	pimpl->playMusic();
+        KimarijiPractice kimariji_practice;
+        kimariji_practice.run();
+        pimpl->playMusic();
 
       } else if (selected == 2) {
-	// ߂
-	quit |= true;
+        // ߂
+        quit |= true;
       }
 
       // j[đI\ɂ
       pimpl->placeComponents();
-      LockGuard guard(pimpl->mutex);
       pimpl->menu->releaseDecided();
     }
 
     input.update_all();
+    gui->update();
     quit |= input.isReleased(SDLK_ESCAPE);
     if (input.haveQuitEvent()) {
       pimpl->common->front_layer->disable();
