@@ -7,27 +7,28 @@
   $Id$
 
   \todo ʂtF[hȂ\
-  \todo ʗ̃Ot\
-  \todo Ot̕\ڂ̓[UɋL^Ă
 */
 
 #include "ResultDrawer.h"
 #include "ResultDrawer_uni.h"
 #include "DrawsDefinition.h"
 #include "SystemDefinition.h"
+#include "ResourceDefinition.h"
 #include "CommonResources.h"
 #include "TypingRecorder.h"
+#include "AccessRecordPC.h"
 #include "GuiManager.h"
 #include "Layer.h"
 #include "InputHandler.h"
 #include "InputEvent.h"
 #include "InputReceiveComponent.h"
 #include "TextSurface.h"
+#include "TextProperty.h"
 #include "TextFadeSurface.h"
 #include "LabelComponent.h"
 #include "MusicManager.h"
-#include "LockGuard.h"
 #include "SdlUtils.h"
+#include "Delay.h"
 #include "UtfString.h"
 
 using namespace beego;
@@ -36,9 +37,9 @@ using namespace beego;
 struct ResultDrawer::pImpl {
   TypingMode typing_mode;
   CommonResources* common;
-  SDL_mutex* mutex;
   bool is_decided;
   InputEvent input_event;
+  TextProperty title_property;
   Surface title_surface;
   Component title_label;
   std::vector<Surface> name_surfaces;
@@ -51,9 +52,10 @@ struct ResultDrawer::pImpl {
 
   pImpl(TypingMode mode)
     : typing_mode(mode), common(CommonResources::getObject()),
-      mutex(common->gui->getMutex()), is_decided(false),
-      title_surface(new TextSurface(common->font, ResultDrawer_title,
-				    WakaDrawSize, Fore, Back, true)),
+      is_decided(false),
+      title_property(common->font, ResultDrawer_title,
+                     WakaDrawSize, Fore, Back, true),
+      title_surface(new TextSurface(title_property)),
       title_label(new LabelComponent(title_surface)) {
   }
 
@@ -62,39 +64,40 @@ struct ResultDrawer::pImpl {
   }
 
   void placeComponents(void) {
-    LockGuard guard(mutex);
     common->front_layer->push_front(title_label);
     for (std::vector<Component>::iterator it = name_labels.begin();
-	 it != name_labels.end(); ++it) {
+         it != name_labels.end(); ++it) {
       common->front_layer->push_front(*it);
     }
     for (std::vector<Component>::iterator it = num_labels.begin();
-	 it != num_labels.end(); ++it) {
+         it != num_labels.end(); ++it) {
       common->front_layer->push_front(*it);
     }
     for (std::vector<Component>::iterator it = unit_labels.begin();
-	 it != unit_labels.end(); ++it) {
+         it != unit_labels.end(); ++it) {
       common->front_layer->push_front(*it);
     }
-    common->front_layer->push_front(common->input_receiver);
+
+    is_decided = false;
+    common->input_receiver->clear();
   }
 
   void removeComponents(void) {
-    LockGuard guard(mutex);
     common->front_layer->remove(title_label);
     for (std::vector<Component>::iterator it = name_labels.begin();
-	 it != name_labels.end(); ++it) {
+         it != name_labels.end(); ++it) {
       common->front_layer->remove(*it);
     }
     for (std::vector<Component>::iterator it = num_labels.begin();
-	 it != num_labels.end(); ++it) {
+         it != num_labels.end(); ++it) {
       common->front_layer->remove(*it);
     }
     for (std::vector<Component>::iterator it = unit_labels.begin();
-	 it != unit_labels.end(); ++it) {
+         it != unit_labels.end(); ++it) {
       common->front_layer->remove(*it);
     }
-    common->front_layer->remove(common->input_receiver);
+
+    //common->front_layer->remove(common->input_receiver);
     common->input_receiver->clear();
   }
 
@@ -114,10 +117,10 @@ struct ResultDrawer::pImpl {
     title_label->setPosition(&position);
 
     // a̐
+    TextProperty text_property(common->font, ResultDrawer_num,
+                               MenuSize, Fore, Back, true);
     name_surfaces.push_back
-      (static_cast<Surface>(new TextFadeSurface(common->font,
-						ResultDrawer_num,
-						MenuSize, Fore, Back, true)));
+      (static_cast<Surface>(new TextFadeSurface(text_property)));
     name_labels.push_back
       (static_cast<Component>(new LabelComponent(name_surfaces.back())));
 
@@ -127,54 +130,50 @@ struct ResultDrawer::pImpl {
     sprintf(buffer, "%d", waka_num);
     std::vector<Uint16> num_text;
     ustrcat(num_text, buffer);
+    text_property.utext = &num_text[0];
     num_surfaces.push_back
-      (static_cast<Surface>(new TextFadeSurface(common->font, &num_text[0],
-						MenuSize, Fore, Back, true)));
+      (static_cast<Surface>(new TextFadeSurface(text_property)));
     num_labels.push_back
       (static_cast<Component>(new LabelComponent(num_surfaces.back())));
+    text_property.utext = ResultDrawer_syu;
+    text_property.size = NormalSize;
     unit_surfaces.push_back
-      (static_cast<Surface>(new TextFadeSurface(common->font,
-						ResultDrawer_syu,
-						NormalSize,
-						Fore, Back, true)));
+      (static_cast<Surface>(new TextFadeSurface(text_property)));
     unit_labels.push_back
       (static_cast<Component>(new LabelComponent(unit_surfaces.back())));
 
     if (typing_mode == ShimonokuTyping) {
       // ^Cvx
+      text_property.utext = ResultDrawer_types;
+      text_property.size = MenuSize;
       name_surfaces.push_back
-	(static_cast<Surface>(new TextFadeSurface(common->font,
-						  ResultDrawer_types,
-						  MenuSize, Fore, Back,
-						  true)));
+        (static_cast<Surface>(new TextFadeSurface(text_property)));
       name_labels.push_back
-	(static_cast<Component>(new LabelComponent(name_surfaces.back())));
+        (static_cast<Component>(new LabelComponent(name_surfaces.back())));
 
       // /b
       num_text.clear();
       double typing_speed = common->recorder->getTypingSpeed();
       sprintf(buffer, "%.1f", typing_speed);
       ustrcat(num_text, buffer);
+      text_property.utext = &num_text[0];
       num_surfaces.push_back
-	(static_cast<Surface>(new TextFadeSurface(common->font, &num_text[0],
-						  MenuSize, Fore, Back,
-						  true)));
+        (static_cast<Surface>(new TextFadeSurface(text_property)));
       num_labels.push_back
-	(static_cast<Component>(new LabelComponent(num_surfaces.back())));
+        (static_cast<Component>(new LabelComponent(num_surfaces.back())));
+      text_property.utext = ResultDrawer_vel;
+      text_property.size = NormalSize;
       unit_surfaces.push_back
-	(static_cast<Surface>(new TextFadeSurface(common->font,
-						  ResultDrawer_vel,
-						  NormalSize,
-						  Fore, Back, true)));
+        (static_cast<Surface>(new TextFadeSurface(text_property)));
       unit_labels.push_back
-	(static_cast<Component>(new LabelComponent(unit_surfaces.back())));
+        (static_cast<Component>(new LabelComponent(unit_surfaces.back())));
     }
 
     // ͊Jn܂ł̎
+    text_property.utext = ResultDrawer_delay;
+    text_property.size = MenuSize;
     name_surfaces.push_back
-      (static_cast<Surface>(new TextFadeSurface(common->font,
-						ResultDrawer_delay,
-						MenuSize, Fore, Back, true)));
+      (static_cast<Surface>(new TextFadeSurface(text_property)));
     name_labels.push_back
       (static_cast<Component>(new LabelComponent(name_surfaces.back())));
 
@@ -183,47 +182,43 @@ struct ResultDrawer::pImpl {
     double delay_sec = common->recorder->getStartDelay();
     sprintf(buffer, "%.2f", delay_sec);
     ustrcat(num_text, buffer);
+    text_property.utext = &num_text[0];
     num_surfaces.push_back
-      (static_cast<Surface>(new TextFadeSurface(common->font, &num_text[0],
-						MenuSize, Fore, Back, true)));
+      (static_cast<Surface>(new TextFadeSurface(text_property)));
     num_labels.push_back
       (static_cast<Component>(new LabelComponent(num_surfaces.back())));
+    text_property.utext = ResultDrawer_sec;
+    text_property.size = NormalSize;
     unit_surfaces.push_back
-      (static_cast<Surface>(new TextFadeSurface(common->font,
-						ResultDrawer_sec,
-						NormalSize,
-						Fore, Back, true)));
+      (static_cast<Surface>(new TextFadeSurface(text_property)));
     unit_labels.push_back
       (static_cast<Component>(new LabelComponent(unit_surfaces.back())));
 
     if (typing_mode == ShimonokuTyping) {
       // ^Cv
+      text_property.utext = ResultDrawer_miss;
+      text_property.size = MenuSize;
       name_surfaces.push_back
-	(static_cast<Surface>(new TextFadeSurface(common->font,
-						  ResultDrawer_miss,
-						  MenuSize, Fore, Back,
-						  true)));
+        (static_cast<Surface>(new TextFadeSurface(text_property)));
       name_labels.push_back
-	(static_cast<Component>(new LabelComponent(name_surfaces.back())));
+        (static_cast<Component>(new LabelComponent(name_surfaces.back())));
 
       // 
       num_text.clear();
       size_t miss_types = common->recorder->getMissTypes();
       sprintf(buffer, "%d", miss_types);
       ustrcat(num_text, buffer);
+      text_property.utext = &num_text[0];
       num_surfaces.push_back
-	(static_cast<Surface>(new TextFadeSurface(common->font, &num_text[0],
-						  MenuSize, Fore, Back,
-						  true)));
+        (static_cast<Surface>(new TextFadeSurface(text_property)));
       num_labels.push_back
-	(static_cast<Component>(new LabelComponent(num_surfaces.back())));
+        (static_cast<Component>(new LabelComponent(num_surfaces.back())));
+      text_property.utext = ResultDrawer_times;
+      text_property.size = NormalSize;
       unit_surfaces.push_back
-	(static_cast<Surface>(new TextFadeSurface(common->font,
-						  ResultDrawer_times,
-						  NormalSize,
-						  Fore, Back, true)));
+        (static_cast<Surface>(new TextFadeSurface(text_property)));
       unit_labels.push_back
-	(static_cast<Component>(new LabelComponent(unit_surfaces.back())));
+        (static_cast<Component>(new LabelComponent(unit_surfaces.back())));
     }
 
     // ĉi̍ڈʒuɂ
@@ -238,26 +233,26 @@ struct ResultDrawer::pImpl {
 
     position.x = (640 - ResultWidth)/2;
     size_t num_pos_right = 640 - (640 - ResultWidth)/2 - unit_max_length;
-    unit_position.x = num_pos_right;
+    unit_position.x = static_cast<int>(num_pos_right);
 
     // ڂ̔zu
     for (std::vector<Component>::iterator it = name_labels.begin();
-	 it != name_labels.end(); ++it) {
+         it != name_labels.end(); ++it) {
       position.y += ResultOffset;
       (*it)->setPosition(&position);
     }
 
     // l̔zu
     for (std::vector<Component>::iterator it = num_labels.begin();
-	 it != num_labels.end(); ++it) {
+         it != num_labels.end(); ++it) {
       num_position.y += ResultOffset;
-      num_position.x = rightPosition(*it, num_pos_right);
+      num_position.x = rightPosition(*it, static_cast<int>(num_pos_right));
       (*it)->setPosition(&num_position);
     }
 
     // Pʂ̔zu
     for (std::vector<Component>::iterator it = unit_labels.begin();
-	 it != unit_labels.end(); ++it) {
+         it != unit_labels.end(); ++it) {
       unit_position.y += ResultOffset;
       (*it)->setPosition(&unit_position);
     }
@@ -275,25 +270,28 @@ ResultDrawer::~ResultDrawer(void) {
 
 void ResultDrawer::createResult(void) {
 
-  // 
-  pimpl->is_decided = false;
-
   // \錋ʂ̌vZ
   pimpl->common->recorder->evaluate();
 
+  // L^̕ۑ
+  //bool AccessRecordPC::record(const recordLine_t& data) {
+
   // R|[lg̐
   pimpl->clearComponents();
   pimpl->updateComponent();
 
   // R|[lg̔zu
+  // !!! ŔzuĂяốAȂ񂩕ςȋC邪A܂Â
   pimpl->placeComponents();
 
-  // y̒~
   if (pimpl->common->music) {
-    pimpl->common->music->stop(StopFadeOut);
+    // y̒~҂
+    pimpl->common->music->stop(3000);
 
-    // ʉ̍Đ
-    // !!!
+    // ʉ̍ĐJn
+    // !!! ýAׂĂ̕\IƂɁAȂ炷xȁH
+    // !!! SoundEffect_2 悩
+    //pimpl->common->music->setNextMusic(BackMusic_4, 1);
   }
 }
 
@@ -311,6 +309,11 @@ void ResultDrawer::placeComponents(void) {
 
 void ResultDrawer::removeComponents(void) {
   pimpl->removeComponents();
+
+  // y̒~
+  if (pimpl->common->music) {
+    pimpl->common->music->halt();
+  }
 }
 
 
