@@ -3,7 +3,7 @@
 
 /*!
   \file
-  \brief ʕ\p Unicode \[X`(̋)
+  \brief ʕ\p Unicode \[X`
 
   \author Satofumi KAMIMURA
 
