@@ -8,6 +8,7 @@
 */
 
 #include "SdlSurface.h"
+#include "ModifySurface.h"
 #include "SdlUtils.h"
 #include "LogManager.h"
 #include <string>
@@ -25,14 +26,14 @@ struct SdlSurface::pImpl {
   bool is_transparent;
   size_t now_percent;
 
-  pImpl(SDL_Surface* sdlSurface, bool transparent_on)
-    : scr(SDL_GetVideoSurface()), surface(sdlSurface), is_changed(false),
+  pImpl(SDL_Surface* surface_, bool transparent_on)
+    : scr(SDL_GetVideoSurface()), surface(surface_), is_changed(false),
       is_transparent(false), now_percent(100) {
 
     if (scr == NULL) {
       LogManager* log = LogManager::getObject();
-      std::string message = "SdlSurface::pImpl(): "
-	"Screen surface must be created.";
+      std::string message =
+        "SdlSurface::pImpl(): Screen surface must be created.";
       log->write(LogManager::Warning, message.c_str());
       return;
     }
@@ -48,27 +49,11 @@ struct SdlSurface::pImpl {
   }
 
   void transparent(void) {
-    if ((surface == NULL) || (scr == NULL)) {
-      return;
+    SDL_Surface* modified = beego::transparent(scr, surface);
+    if (modified) {
+      surface = modified;
+      is_transparent = true;
     }
-
-    Uint32 trans_color = 0;
-    if (surface->format->BitsPerPixel == 8) {
-      // sNZtH[}bg 8 bit ̏ꍇ
-      Uint8 index = *(Uint8 *)surface->pixels;
-      SDL_Color& color = surface->format->palette->colors[index];
-      trans_color = SDL_MapRGB(surface->format, color.r, color.g, color.b);
-    } else {
-      trans_color = *(Uint32*)surface->pixels;
-    }
-
-    SDL_SetColorKey(surface,
-		    SDL_SRCCOLORKEY | SDL_RLEACCEL, trans_color);
-    SDL_Surface* transparent_surface = SDL_DisplayFormat(surface);
-    SDL_FreeSurface(surface);
-    surface = transparent_surface;
-
-    is_transparent = true;
   }
 };
 
@@ -93,16 +78,18 @@ void SdlSurface::transparent(void) {
 
 
 void SdlSurface::draw(std::vector<SDL_Rect>& update_rects,
-		      const SDL_Rect* pos, const SDL_Rect* area,
-		      size_t ticks) {
+                      const SDL_Rect* pos, const SDL_Rect* area,
+                      size_t ticks) {
 
   if ((pimpl->scr == NULL) &&
       ((pimpl->scr = SDL_GetVideoSurface()) == NULL)) {
     return;
   }
 
+  //fprintf(stderr, "SdlSurface::draw: %d, %d, %d, %d\n", pos->x, pos->y, pos->w, pos->h);
+
   SDL_BlitSurface(pimpl->surface, const_cast<SDL_Rect*>(area),
-		  pimpl->scr, const_cast<SDL_Rect*>(pos));
+                  pimpl->scr, const_cast<SDL_Rect*>(pos));
   update_rects.push_back(*pos);
 }
 
@@ -135,13 +122,13 @@ bool SdlSurface::isTransparent(void) {
 
 
 void SdlSurface::setAlpha(size_t percent) {
-  percent = (percent > 100) ? 100 : percent;
-  if ((percent != pimpl->now_percent) && pimpl->surface) {
 
-    SDL_SetAlpha(pimpl->surface, SDL_SRCALPHA,
-		 percent * SDL_ALPHA_OPAQUE / 100);
+  size_t modified_percent = beego::setAlpha(percent,
+                                            pimpl->now_percent,
+                                            pimpl->surface);
 
-    pimpl->now_percent = percent;
+  if (modified_percent != pimpl->now_percent) {
+    pimpl->now_percent = modified_percent;
     pimpl->is_changed = true;
     pimpl->is_transparent = (percent >= 100) ? false : true;
   }
