@@ -15,6 +15,7 @@
 
 
 namespace beego {
+
   namespace SDL {
     /*!
       \brief SDL ̉ʑNX
@@ -24,7 +25,7 @@ namespace beego {
       SdlVideo& operator = (const SdlVideo& rhs);
 
       struct pImpl;
-      const std::auto_ptr<pImpl> pimpl;
+      pImpl* pimpl;
 
     public:
       SdlVideo(void);
