@@ -6,16 +6,14 @@
 
   $Id$
 
-  \todo ͂AtF[h̉ӏSĕ\
-  \todo ͗zē͂ł̂h~
   \todo ͕@̕ύX̂߂ɁARXgN^č\zdg݂
   \todo J[\\
   \todo BS, s̉摜ׂ́Ah炵Ȃ\
-  \todo ԈႢ͂́AςĒʒm
 */
 
 #include "ShimonokuInput.h"
 #include "DrawsDefinition.h"
+#include "ResourceDefinition.h"
 #include "CommonResources.h"
 #include "WakaDrawer.h"
 #include "WakaData.h"
@@ -23,12 +21,12 @@
 #include "GuiManager.h"
 #include "Layer.h"
 #include "TextInputComponent.h"
-#include "LockGuard.h"
+#include "TextProperty.h"
 #include "SdlUtils.h"
 #include "GetTicks.h"
 #include "UtfString.h"
 #include "RomanCreator.h"
-#include <string>
+#include "SoundEffectManager.h"
 
 using namespace beego;
 
@@ -36,9 +34,9 @@ using namespace beego;
 struct ShimonokuInput::pImpl {
   TypingMode typing_mode;
   CommonResources* common;
-  SDL_mutex* mutex;
   WakaDrawer waka_drawer;
   int input_complete;
+  TextProperty text_property;
   boost::shared_ptr<TextInputComponent> text_input;
   TypingTextConverter converter;
   size_t start_ticks;
@@ -47,17 +45,17 @@ struct ShimonokuInput::pImpl {
   std::vector<std::vector<Uint16> > judge_text;
   RomanCreator roman_creator;
   std::string roman_complete_sample[2];
+  bool pre_need_bs;
 
   pImpl(TypingMode mode)
     : typing_mode(mode), common(CommonResources::getObject()),
-      mutex(common->gui->getMutex()), waka_drawer(typing_mode),
-      input_complete(0),
-      text_input(new TextInputComponent(InputWidth, InputSize, common->font,
-					WakaDrawSize, White, Black, false,
-					TextOffset,
-					(InputSize - WakaDrawSize) / 2)),
+      waka_drawer(typing_mode), input_complete(0),
+      text_property(common->font, "", WakaDrawSize, White, Black, false),
+      text_input(new TextInputComponent(InputWidth, InputSize, text_property,
+                                        TextOffset,
+                                        (InputSize - WakaDrawSize) / 2)),
       converter(common->convert_type), start_ticks(0),
-      waka_index(0), waka_no(0) {
+      waka_index(0), waka_no(0), pre_need_bs(false) {
 
     // !!! ȑOɁArecorder ̕ϊ[h蒼ĂKv
     // !!! ̂ŁATypingTextConverter ̕ϊ[h蒼AH
@@ -71,13 +69,12 @@ struct ShimonokuInput::pImpl {
     // !!! C[ɓo^܂ł́AbNȂĂ悢
     SDL_Rect position;
     set_SdlRect(&position, (640 - InputWidth)/2,
-		bottomPosition(text_input, 480) - BottomOffset);
+                bottomPosition(text_input, 480) - BottomOffset);
     text_input->setPosition(&position);
     text_input->swapTextConverter(&converter);
   }
 
   void clearInputState(void) {
-    LockGuard guard(mutex);
     text_input->clear();
     text_input->releaseDecided();
   }
@@ -89,15 +86,15 @@ struct ShimonokuInput::pImpl {
       size_t n = ustrlen(KanaWaka[waka_no][i]);
 
       for (size_t j = 0; j < n; ++j) {
-	Uint16 uch = KanaWaka[waka_no][i][j];
-	if (uch == 0x3090) {
-	  // : 0x3090 -> 0x3044
-	  uch = 0x3044;
-	} else if (uch == 0x3091) {
-	  // : 0x3091 -> 0x3048
-	  uch = 0x3048;
-	}
-	judge_text[i].push_back(uch);
+        Uint16 uch = KanaWaka[waka_no][i][j];
+        if (uch == 0x3090) {
+          // : 0x3090 -> 0x3044
+          uch = 0x3044;
+        } else if (uch == 0x3091) {
+          // : 0x3091 -> 0x3048
+          uch = 0x3048;
+        }
+        judge_text[i].push_back(uch);
       }
       judge_text[i].push_back(0x0);
     }
@@ -106,8 +103,8 @@ struct ShimonokuInput::pImpl {
     for (int i = 0; i < 2; ++i) {
       std::vector<Uint16> roman_sample = judge_text[i + 3];
       if (typing_mode == KimarijiTyping) {
-	// ̋͂̂Ƃ́AQ݂̂̓͌ɂ
-	roman_sample[2] = 0x0;
+        // ̋͂̂Ƃ́AQ݂̂̓͌ɂ
+        roman_sample[2] = 0x0;
       }
       roman_creator.convert(roman_complete_sample[i], &roman_sample[0]);
     }
@@ -118,13 +115,11 @@ struct ShimonokuInput::pImpl {
     // ͂ꂽ[}ϊ
     std::vector<Uint16> inputed_text;
     std::string inputed_roman;
-    LockMutex(mutex);
     //fprintf(stderr, "at ShimonokuInput::createRomanSample()\n");
     if (text_input->getBuffer(inputed_text) > 0) {
       RomanCreator roman_creator;
       roman_creator.convert(inputed_roman, &inputed_text[0]);
     }
-    UnlockMutex(mutex);
 
     // ̋ʕ菜Ԃ
     // !!! Ƃ肠Aׂō
@@ -134,14 +129,14 @@ struct ShimonokuInput::pImpl {
     size_t i = 0;
     for (; i < n; ++i) {
       if (inputed_roman[i] != roman_complete_sample[input_complete][i]) {
-	break;
+        break;
       }
     }
     roman_sample = &roman_complete_sample[input_complete][i];
     bool need_bs = true;
     if (((i == 0) && (input_n == 0)) ||
-	((i == complete_n) && (i == input_n)) ||
-	((i + 1) == input_n)) {
+        ((i == complete_n) && (i == input_n)) ||
+        ((i + 1) == input_n)) {
       need_bs = false;
     }
     return need_bs;
@@ -166,6 +161,7 @@ void ShimonokuInput::setNextWaka(void) {
 
 
 void ShimonokuInput::updateWaka(void) {
+  //fprintf(stderr, "ShimonokuInput::updateWaka()\n");
 
   pimpl->waka_no = pimpl->common->waka_order[pimpl->waka_index];
 
@@ -204,24 +200,27 @@ void ShimonokuInput::drawWaka(void) {
 
 void ShimonokuInput::drawInput(void) {
 
-  LockMutex(pimpl->mutex);
-  //fprintf(stderr, "at ShimonokuInput::drawInput()\n");
   if (! pimpl->text_input->isChanged()) {
-    UnlockMutex(pimpl->mutex);
     return;
   }
-  UnlockMutex(pimpl->mutex);
 
   // [}͌̍쐬
   std::string roman_sample;
   bool need_bs = pimpl->createRomanSample(roman_sample);
 
+  // need_bs ̕\̓͂ŁAʉ炷B폜L[͗O
+  if ((! pimpl->text_input->isErased()) && (need_bs == true)) {
+    if (pimpl->common->music) {
+      // ʉ̍Đ
+      pimpl->common->sound_effect->play(Miss);
+    }
+  }
+  pimpl->pre_need_bs = need_bs;
+
   // ͌̍XV
-  LockGuard guard(pimpl->mutex);
-  //fprintf(stderr, "at ShimonokuInput::drawInput()\n");
   pimpl->waka_drawer.updateInputSample(pimpl->judge_text,
-				       pimpl->input_complete, roman_sample,
-				       need_bs);
+                                       pimpl->input_complete, roman_sample,
+                                       need_bs);
 
   // ̋^CsÔƂ́A͂m肳ĂȂ΁A肵Ȃ
   if (pimpl->typing_mode == ShimonokuTyping) {
@@ -243,7 +242,7 @@ void ShimonokuInput::drawInput(void) {
   case ShimonokuTyping:
     // ͂̔
     if ((inputed_length > 0) && (n == inputed_length) &&
-	(! ustrncmp(&pimpl->judge_text[ku_index][0], &buffer[0], n))) {
+        (! ustrncmp(&pimpl->judge_text[ku_index][0], &buffer[0], n))) {
 
       size_t ticks = GetTicks() - pimpl->start_ticks;
       pimpl->common->recorder->recordTyping(TypingRecorder::Complete, ticks);
@@ -256,7 +255,7 @@ void ShimonokuInput::drawInput(void) {
   case KimarijiTyping:
     // ŏ̂Qœ͔s
     if ((inputed_length >= 2) &&
-	(! ustrncmp(&pimpl->judge_text[ku_index][0], &buffer[0], 2))) {
+        (! ustrncmp(&pimpl->judge_text[ku_index][0], &buffer[0], 2))) {
       ++pimpl->input_complete;
       pimpl->clearInputState();
     }
@@ -283,7 +282,6 @@ bool ShimonokuInput::isComplete(void) {
 
 
 void ShimonokuInput::placeComponents(void) {
-  LockGuard guard(pimpl->mutex);
   pimpl->common->front_layer->push_front(pimpl->text_input);
 }
 
@@ -295,11 +293,10 @@ void ShimonokuInput::removeComponents(void) {
 
 
 void ShimonokuInput::removeInputComponents(void) {
-    pimpl->waka_drawer.removeInputComponents();
+  pimpl->waka_drawer.removeInputComponents();
 
-    LockGuard guard(pimpl->mutex);
-    pimpl->text_input->clear();
-    pimpl->common->front_layer->remove(pimpl->text_input);
+  pimpl->text_input->clear();
+  pimpl->common->front_layer->remove(pimpl->text_input);
 }
 
 
