@@ -9,7 +9,6 @@
   \todo ca̐ɕ\
   \todo rݏグ@\̒ǉ
   \todo L[\
-  \todo a̓͌ɔƁA̘a̓͂ł
 */
 
 #include "ShimonokuPractice.h"
@@ -17,10 +16,11 @@
 #include "PracticeMenu_uni.h"
 #include "DrawsDefinition.h"
 #include "SystemDefinition.h"
+#include "ResourceDefinition.h"
 #include "ShimonokuInput.h"
 #include "CommonResources.h"
-#include "ResourceDefinition.h"
 #include "ResultDrawer.h"
+#include "GraphDrawer.h"
 #include "TypingRecorder.h"
 #include "ShuffleWaka.h"
 #include "GuiManager.h"
@@ -28,16 +28,18 @@
 #include "BaseEntity.h"
 #include "StateMachine.h"
 #include "MusicManager.h"
+#include "SoundEffectManager.h"
 #include "GetTicks.h"
 #include "Delay.h"
 #include "TextSurface.h"
+#include "TextProperty.h"
 #include "LabelComponent.h"
 #include "SdlUtils.h"
 #include "InputHandler.h"
 #include "InputEvent.h"
 #include "InputReceiveComponent.h"
-#include "LockGuard.h"
 #include "UtfString.h"
+#include <time.h>
 
 using namespace beego;
 
@@ -99,9 +101,8 @@ struct ShimonokuPractice::pImpl {
     void exit(Schedule* type) {
 
       // Q[̋L^
-      int rand_seed = time(NULL);
-      //rand_seed = ShuffleWaka::InvalidSeed; // 
-      //rand_seed = 0; // Ȃ
+      int rand_seed = static_cast<int>(time(NULL));
+      //rand_seed = ShuffleWaka::NoShuffleSeed;
 
       // â̏ԂVbt
       ShuffleWaka wakaShuffle(ShimonokuTyping, rand_seed);
@@ -118,8 +119,8 @@ struct ShimonokuPractice::pImpl {
   class PrologueState : public State<Schedule> {
 
     CommonResources* common;
-    SDL_mutex* mutex;
     // !!! `܂͕ʃNXɂA肷邩
+    TextProperty title_property;
     Surface title_surface;
     Component title_label;
     Surface subTitle_surface;
@@ -127,11 +128,11 @@ struct ShimonokuPractice::pImpl {
     size_t first_ticks;
 
     PrologueState(CommonResources* common_obj)
-      : common(common_obj), mutex(common->gui->getMutex()),
-	title_surface(new TextSurface(common->font,
-				      PracticeMenu_shimonoku, TitleSize,
-				      Fore, Back, true)),
-	title_label(new LabelComponent(title_surface)) {
+      : common(common_obj),
+        title_property(common->font, PracticeMenu_shimonoku, TitleSize,
+                       Fore, Back, true),
+        title_surface(new TextSurface(title_property)),
+        title_label(new LabelComponent(title_surface)) {
     }
 
   public:
@@ -145,7 +146,7 @@ struct ShimonokuPractice::pImpl {
       // ű^CsOvƕ\
       SDL_Rect position;
       set_SdlRect(&position, centerPosition(title_label, 640/2),
-		  middlePosition(title_label, 480/4 + SubOffset));
+                  middlePosition(title_label, 480/4 + SubOffset));
       title_label->setPosition(&position);
 
       // uX ṽx쐬
@@ -154,28 +155,29 @@ struct ShimonokuPractice::pImpl {
       sprintf(buffer, "%d", common->practice_num);
       ustrcat(num_str, buffer);
       ustrcat(num_str, ShimonokuPractice_PrologueSubTitle);
-      Surface new_surface(new TextSurface(common->font, &num_str[0],
-					  LargeSize, Fore, Back, true));
+      TextProperty text_property(common->font, &num_str[0],
+                                 LargeSize, Fore, Back, true);
+      Surface new_surface(new TextSurface(text_property));
       std::swap(new_surface, subTitle_surface);
 
       Component new_label(new LabelComponent(subTitle_surface));
       std::swap(new_label, subTitle_label);
 
       set_SdlRect(&position, centerPosition(subTitle_label, 640/2),
-		  topPosition(subTitle_label, 480/4 + MenuOffset) + SubOffset);
+                  topPosition(subTitle_label, 480/4 + MenuOffset) + SubOffset);
       subTitle_label->setPosition(&position);
 
       placeComponents();
 
       if (common->music) {
-	// !!! dg݂A܂莚Aʕ\̂ɂKp邱
-	// y̒~҂
-	while (common->music->nowPlaying()) {
-	  delay(10);
-	}
+        // y̒~҂
+        // !!! ^CAEgł悤ɂׂ
+        while (common->music->nowPlaying()) {
+          delay(10);
+        }
 
-	// ʉ̍ĐJn
-	// !!!
+        // ʉ̍ĐJn
+        common->sound_effect->play(SoundEffect_1);
       }
       first_ticks = GetTicks();
     }
@@ -183,58 +185,55 @@ struct ShimonokuPractice::pImpl {
     void execute(Schedule* type) {
 
       // ҋ@Ԃo߂ATypingState ֑Jڂ
-      // !!!
-      // !!! ҋ@Ԃ́Aʉ̍ĐԂ
-
-      // !!! ̑ҋ@Ԃ́Aʉ
       InputEvent input_event;
       common->input_receiver->updateInputEvent(input_event);
       size_t spent_msec = GetTicks() - first_ticks;
       if ((spent_msec >= PrologueMsec) ||
-	  (InputEvent::isReleased(input_event, SDLK_RETURN))) {
-	type->changeState(TypingState::getObject(common));
+          (InputEvent::isReleased(input_event, SDLK_RETURN))) {
+        type->changeState(TypingState::getObject(common));
       }
     }
 
     void exit(Schedule* type) {
+
       // zuR|[lg폜
       removeComponents();
 
-      // ʉ̒~
-      // !!!
-
-      // y̍Đ
+      // ʉ̒~ƁAy̍Đ
       if (common->music) {
-	common->music->setNextMusic(BackMusic_2);
+
+        // y̍Đ
+        common->music->setNextMusic(BackMusic_2);
       }
     }
 
     void placeComponents(void) {
-      LockGuard guard(mutex);
       common->front_layer->push_front(title_label);
       common->front_layer->push_front(subTitle_label);
-      common->front_layer->push_front(common->input_receiver);
+
+      common->input_receiver->clear();
     }
 
     void removeComponents(void) {
-      LockGuard guard(mutex);
       common->front_layer->remove(title_label);
       common->front_layer->remove(subTitle_label);
-      common->front_layer->remove(common->input_receiver);
+
+      if (common->music) {
+        common->sound_effect->stop();
+      }
     }
   };
 
   class TypingState : public State<Schedule> {
     CommonResources* common;
-    SDL_mutex* mutex;
     ShimonokuInput shimonoku_input;
     InputEvent input_event;
-    int practice_left;
+    size_t practice_left;
     bool typing_complete;
 
     TypingState(CommonResources* common_obj)
-      : common(common_obj), mutex(common->gui->getMutex()),
-	shimonoku_input(ShimonokuTyping), typing_complete(false) {
+      : common(common_obj),
+        shimonoku_input(ShimonokuTyping), typing_complete(false) {
     }
 
   public:
@@ -243,7 +242,7 @@ struct ShimonokuPractice::pImpl {
       return &obj;
     }
 
-    void setPracticeNum(int num) {
+    void setPracticeNum(size_t num) {
       practice_left = num;
     }
 
@@ -255,9 +254,7 @@ struct ShimonokuPractice::pImpl {
       typing_complete = false;
       shimonoku_input.updateWaka();
 
-      LockGuard guard(mutex);
-      //fprintf(stderr, "at TypingState::enter()\n");
-      common->front_layer->push_front(common->input_receiver);
+      common->input_receiver->clear();
     }
 
     void execute(Schedule* type) {
@@ -269,33 +266,38 @@ struct ShimonokuPractice::pImpl {
       common->input_receiver->updateInputEvent(input_event);
       if (typing_complete) {
 
-	// s̓͂҂
-	if (! InputEvent::isPressed(input_event, SDLK_RETURN)) {
-	  return;
-	}
+        // s̓͂҂
+        if (! InputEvent::isPressed(input_event, SDLK_RETURN)) {
+          return;
+        }
 
-	typing_complete = false;
-	if (practice_left <= 0) {
-	  // KAResultState ֑Jڂ
-	  type->changeState(ResultState::getObject(common));
-	} else {
-	  // ēxAâ̓͂s
-	  shimonoku_input.setNextWaka();
-	  type->changeState(TypingState::getObject(common));
-	}
-	return;
+        typing_complete = false;
+        if (practice_left <= 0) {
+          // KAResultState ֑Jڂ
+          type->changeState(ResultState::getObject(common));
+        } else {
+          // ēxAâ̓͂s
+          shimonoku_input.setNextWaka();
+          type->changeState(TypingState::getObject(common));
+        }
+        return;
       }
 
       // ̋̓͗
       if (! typing_complete) {
-	shimonoku_input.drawInput();
+        shimonoku_input.drawInput();
       }
 
       // ͂玟̘â
       if (shimonoku_input.isComplete()) {
-	--practice_left;
-	shimonoku_input.removeInputComponents();
-	typing_complete = true;
+        --practice_left;
+        shimonoku_input.removeInputComponents();
+        typing_complete = true;
+
+        if (common->music) {
+          // ʉ̍Đ
+          common->sound_effect->play(Decide);
+        }
       }
     }
 
@@ -342,9 +344,10 @@ struct ShimonokuPractice::pImpl {
       size_t ticks = GetTicks() - first_ticks;
       result_drawer.drawResult(ticks);
 
-      // L[͂ȂǂŁAI
+      // L[͂ȂǂŁAOt\
       if (result_drawer.keyPressed()) {
-	type->changeState(WaitKeyState::getObject(common));
+        type->changeState(WaitKeyState::
+                          getObject(common, GraphState::getObject(common)));
       }
     }
 
@@ -356,32 +359,73 @@ struct ShimonokuPractice::pImpl {
     }
   };
 
-  // !!! ̃NX́ÂƋʂɂȂ̂ŁA肽
-  class WaitKeyState : public State<Schedule> {
+  class GraphState : public State<Schedule> {
     CommonResources* common;
-    SDL_mutex* mutex;
-    InputEvent input_event;
+    GraphDrawer graph_drawer;
 
-    WaitKeyState(CommonResources* common_obj)
-      : common(common_obj), mutex(common->gui->getMutex()) {
+    GraphState(CommonResources* common_obj)
+      : common(common_obj), graph_drawer(ShimonokuTyping) {
+
+      // Otp̏擾Agraph_drawer ɓn
+      // !!!
     }
 
   public:
-    static WaitKeyState* getObject(CommonResources* common) {
-      static WaitKeyState obj(common);
+    static GraphState* getObject(CommonResources* common) {
+      static GraphState obj(common);
       return &obj;
     }
 
     void enter(Schedule* type) {
-      LockGuard guard(mutex);
-      //fprintf(stderr, "at WaitKeyState::enter()\n");
-      common->front_layer->push_front(common->input_receiver);
+
+      // ʕ\̍폜
+      ResultState::getObject(common)->removeComponents();
+
+      // Ot̕`
+      graph_drawer.drawGraph();
+    }
+
+    void execute(Schedule* type) {
+
+      // L[͂ȂǂŁAI
+      if (graph_drawer.keyPressed()) {
+        type->changeState(FirstState::getObject(common));
+      }
+    }
+
+    void exit(Schedule* type) {
+    }
+
+    void removeComponents(void) {
+      graph_drawer.removeComponents();
+    }
+  };
+
+  // !!! ̃NX́ÂƋʂɂȂ̂ŁA肽
+  class WaitKeyState : public State<Schedule> {
+    CommonResources* common;
+    InputEvent input_event;
+    State<Schedule>* next_state;
+
+    WaitKeyState(CommonResources* common_obj, State<Schedule>* next_state_)
+      : common(common_obj), next_state(next_state_) {
+    }
+
+  public:
+    static WaitKeyState* getObject(CommonResources* common,
+                                   State<Schedule>* next_state) {
+      static WaitKeyState obj(common, next_state);
+      return &obj;
+    }
+
+    void enter(Schedule* type) {
+      common->input_receiver->clear();
     }
 
     void execute(Schedule* type) {
       common->input_receiver->updateInputEvent(input_event);
       if (InputEvent::isReleased(input_event, SDLK_RETURN)) {
-	type->changeState(FirstState::getObject(common));
+        type->changeState(next_state);
       }
     }
 
@@ -390,9 +434,6 @@ struct ShimonokuPractice::pImpl {
     }
 
     void removeComponents(void) {
-      LockGuard guard(mutex);
-      //fprintf(stderr, "at WaitKeyState::removeComponents()\n");
-      common->front_layer->remove(common->input_receiver);
     }
   };
 
@@ -409,7 +450,8 @@ struct ShimonokuPractice::pImpl {
     PrologueState::getObject(common)->removeComponents();
     TypingState::getObject(common)->removeComponents();
     ResultState::getObject(common)->removeComponents();
-    WaitKeyState::getObject(common)->removeComponents();
+    GraphState::getObject(common)->removeComponents();
+    WaitKeyState::getObject(common, NULL)->removeComponents();
   }
 };
 
@@ -424,6 +466,7 @@ ShimonokuPractice::~ShimonokuPractice(void) {
 
 void ShimonokuPractice::run(void) {
 
+  GuiManager* gui = pimpl->common->gui;
   InputHandler& input = *pimpl->common->input;
   bool quit = false;
   bool escape_pressed = false;
@@ -435,15 +478,15 @@ void ShimonokuPractice::run(void) {
     // I
     quit |= pimpl->scheduler.isTerminated();
     input.update_all();
+    gui->update();
     if (input.haveQuitEvent()) {
       pimpl->common->front_layer->disable();
       quit |= true;
     }
     if (pImpl::TypingState::getObject(pimpl->common)->textEmpty()) {
-      // !!! ̂́AGȎdg݂͂ȂƂȂ...
       escape_pressed |= input.isPressed(SDLK_ESCAPE);
       if (escape_pressed && input.isReleased(SDLK_ESCAPE)) {
-	quit |= true;
+        quit |= true;
       }
     }
     delay(1);
