@@ -28,7 +28,7 @@ class ShuffleWaka {
 
 public:
   enum {
-    InvalidSeed = -1,
+    NoShuffleSeed = -1,
   };
 
   /*!
@@ -36,7 +36,7 @@ public:
 
     \param seed [i] _V[h
 
-    \attention seed  InvalidSeed w肷Ƙâ̕тꊷȂ
+    \attention seed  NoShuffleSeed w肷Ƙâ̕тꊷȂ
   */
   ShuffleWaka(TypingMode mode, int seed);
   ~ShuffleWaka(void);
