@@ -15,7 +15,9 @@ using namespace beego;
 
 
 struct SwitchSurface::pImpl {
-  SDL_Rect position;
+  enum {
+    InvalidIndex = -1,
+  };
   int now_index;
   bool is_changed;
 
@@ -26,8 +28,7 @@ struct SwitchSurface::pImpl {
   };
   std::vector<EachSurface> surfaces;
 
-  pImpl(void) : now_index(-1), is_changed(false) {
-    set_SdlRect(&position, 0, 0, 0, 0);
+  pImpl(void) : now_index(InvalidIndex), is_changed(false) {
   }
 };
 
@@ -41,8 +42,8 @@ SwitchSurface::~SwitchSurface(void) {
 
 
 void SwitchSurface::draw(std::vector<SDL_Rect>& update_rects,
-			 const SDL_Rect* pos, const SDL_Rect* area,
-			 size_t ticks) {
+                         const SDL_Rect* pos, const SDL_Rect* area,
+                         size_t ticks) {
   if (pimpl->now_index < 0) {
     return;
   }
@@ -93,12 +94,25 @@ bool SwitchSurface::isChanged(void) {
 
 
 bool SwitchSurface::isTransparent(void) {
+  if (pimpl->now_index < 0) {
+    return true;
+  }
   return pimpl->surfaces[pimpl->now_index].surface->isTransparent();
 }
 
 
+void SwitchSurface::clear(void) {
+  pimpl->surfaces.clear();
+}
+
+
+size_t SwitchSurface::size(void) {
+  return pimpl->surfaces.size();
+}
+
+
 void SwitchSurface::registerSurface(Surface surface,
-				    int x_offset, int y_offset, size_t index) {
+                                    int x_offset, int y_offset, size_t index) {
 
   // w index ̗̈m
   if (index >= pimpl->surfaces.size()) {
@@ -120,13 +134,18 @@ void SwitchSurface::registerSurface(Surface surface,
 void SwitchSurface::switchSurface(size_t index) {
   if (index < pimpl->surfaces.size()) {
     if (pimpl->now_index != static_cast<int>(index)) {
-      pimpl->now_index = index;
+      pimpl->now_index = static_cast<int>(index);
       pimpl->is_changed = true;
     }
   }
 }
 
 
-size_t SwitchSurface::getIndex(void) {
+size_t SwitchSurface::getSurfaceIndex(void) {
   return pimpl->now_index;
 }
+
+
+Surface SwitchSurface::getSurface(size_t index) {
+  return pimpl->surfaces[index].surface;
+}
