@@ -28,17 +28,20 @@ namespace beego {
     ~SwitchSurface(void);
 
     void draw(std::vector<SDL_Rect>& update_rects,
-	      const SDL_Rect* pos, const SDL_Rect* area, size_t ticks);
+              const SDL_Rect* pos, const SDL_Rect* area, size_t ticks);
     size_t getWidth(void);
     size_t getHeight(void);
     void forceSetChanged(void);
     bool isChanged(void);
     bool isTransparent(void);
 
+    void clear(void);
+    size_t size(void);
     void registerSurface(Surface surface,
-			 int x_offset, int y_offset, size_t index);
+                         int x_offset, int y_offset, size_t index);
     void switchSurface(size_t index);
-    size_t getIndex(void);
+    size_t getSurfaceIndex(void);
+    Surface getSurface(size_t index);
   };
 };
 
