@@ -29,20 +29,21 @@ enum {
   ShimonokuPlaying = 3000,
   YomibitoPlaying = 1000,
 #else
-  KaminokuPlaying = 3,
-  ShimonokuPlaying = 2,
-  YomibitoPlaying = 1,
+  KaminokuPlaying = 45,
+  ShimonokuPlaying = 30,
+  YomibitoPlaying = 10,
 #endif
   TotalPlaying = KaminokuPlaying + ShimonokuPlaying,
 };
 
+// Web ANZX̃^CAEg
+enum {
+  WebAccessTimeout = 3000,
+};
+
 // ʂ̑ҋ@
 enum {
-#if 1
-  PrologueMsec = 1500,		//!< v[OԂ̑ҋ@ [msec]
-#else
-  PrologueMsec = 1,
-#endif
+  PrologueMsec = 5100,          //!< v[OԂ̑ҋ@ [msec]
 };
 
 // y̍Đ܂
