@@ -8,6 +8,7 @@
 */
 
 #include "TextFadeSurface.h"
+#include "TextProperty.h"
 #include "TextSurface.h"
 
 using namespace beego;
@@ -22,36 +23,38 @@ struct TextFadeSurface::pImpl {
     size_t height;
 
     void pushSurface(Uint16 ch, TtfResource* font, size_t size,
-		     Uint32 fore, Uint32 back, bool transparent) {
+                     Uint32 fore, Uint32 back, bool transparent) {
       Uint16 text[2] = { 0x0, 0x0 };
       text[0] = ch;
-      boost::shared_ptr<TextSurface>
-	surface(new TextSurface(font, text, size, fore, back, transparent));
+      TextProperty text_property(font, text, size, fore, back, transparent);
+      boost::shared_ptr<TextSurface> surface(new TextSurface(text_property));
       ch_positions.push_back(width);
       width += surface->getWidth();
       size_t surface_height = surface->getHeight();
       if (height < surface_height) {
-	height = surface_height;
+        height = surface_height;
       }
       ch_surfaces.push_back(surface);
     }
 
   public:
-    NormalTextFade(TtfResource* font, const char* text, size_t size,
-		   Uint32 fore, Uint32 back, bool transparent)
-      : width(0), height(0) {
+    NormalTextFade(const TextProperty& property) : width(0), height(0) {
 
-      for (int i = 0; text[i] != '\0'; ++i) {
-	pushSurface(text[i], font, size, fore, back, transparent);
-      }
-    }
-
-    NormalTextFade(TtfResource* font, const Uint16* text, size_t size,
-		   Uint32 fore, Uint32 back, bool transparent)
-      : width(0), height(0) {
-
-      for (int i = 0; text[i] != '\0'; ++i) {
-	pushSurface(text[i], font, size, fore, back, transparent);
+      // !!! ꂵBuvAu
+      // !!! Ƃ肠A
+      TtfResource* font = property.font;
+      size_t size = property.size;
+      Uint32 fore = property.fore_color;
+      Uint32 back = property.back_color;
+      bool transparent = property.transparent;
+      if (property.text) {
+        for (int i = 0; property.text[i] != '\0'; ++i) {
+          pushSurface(property.text[i], font, size, fore, back, transparent);
+        }
+      } else {
+        for (int i = 0; property.utext[i] != '\0'; ++i) {
+          pushSurface(property.utext[i], font, size, fore, back, transparent);
+        }
       }
     }
 
@@ -86,34 +89,16 @@ struct TextFadeSurface::pImpl {
   size_t fade_width;
   size_t now_percent;
 
-  // !!! ȉ pImpl() ́Aǂ狤ʉł̂ȁH
-  // ֐̃ev[gƂH
-
-  pImpl(TtfResource* font, const char* text, size_t size,
-	Uint32 fore, Uint32 back, bool transparent)
-    : fade_mode(FadeInFromLeft),
-      normal_fade(new NormalTextFade(font, text, size,
-				     fore, back, transparent)),
+  pImpl(const TextProperty& property)
+    : fade_mode(FadeInFromLeft), normal_fade(new NormalTextFade(property)),
       fade_obj(normal_fade), is_changed(false), now_percent(100) {
-
-    setFadeMode(fade_mode, size * DefaultFontNum);
-    initAlphaValue();
-  }
-
-  pImpl(TtfResource* font, const Uint16* text, size_t size,
-	Uint32 fore, Uint32 back, bool transparent)
-    : fade_mode(FadeInFromLeft),
-      normal_fade(new NormalTextFade(font, text, size,
-				     fore, back, transparent)),
-      fade_obj(normal_fade), is_changed(false), now_percent(100) {
-
-    setFadeMode(fade_mode, size * DefaultFontNum);
+    setFadeMode(fade_mode, property.size * DefaultFontNum);
     initAlphaValue();
   }
 
   pImpl(FadeSurfacesInterface* fade, size_t fade_width)
-    : fade_mode(FadeInFromLeft),
-      normal_fade(NULL), fade_obj(fade), is_changed(false), now_percent(100) {
+    : fade_mode(FadeInFromLeft), normal_fade(NULL),
+      fade_obj(fade), is_changed(false), now_percent(100) {
 
     setFadeMode(fade_mode, fade_width);
     initAlphaValue();
@@ -141,22 +126,13 @@ struct TextFadeSurface::pImpl {
 };
 
 
-TextFadeSurface::TextFadeSurface(TtfResource* font, const char* text,
-				 size_t size, Uint32 fore_color,
-				 Uint32 back_color, bool transparent)
-  : pimpl(new pImpl(font, text, size, fore_color, back_color, transparent)) {
-}
-
-
-TextFadeSurface::TextFadeSurface(TtfResource* font, const Uint16* text,
-				 size_t size, Uint32 fore_color,
-				 Uint32 back_color, bool transparent)
-  : pimpl(new pImpl(font, text, size, fore_color, back_color, transparent)) {
+TextFadeSurface::TextFadeSurface(const TextProperty& property)
+  : pimpl(new pImpl(property)) {
 }
 
 
 TextFadeSurface::TextFadeSurface(FadeSurfacesInterface* fade,
-				 size_t fade_width)
+                                 size_t fade_width)
   : pimpl(new pImpl(fade, fade_width)) {
 }
 
@@ -166,8 +142,8 @@ TextFadeSurface::~TextFadeSurface(void) {
 
 
 void TextFadeSurface::draw(std::vector<SDL_Rect>& update_rects,
-			   const SDL_Rect* pos, const SDL_Rect* area,
-			   size_t ticks) {
+                           const SDL_Rect* pos, const SDL_Rect* area,
+                           size_t ticks) {
   if (pimpl->fade_width == 0) {
     // T[tFXȂꍇ
     return;
@@ -180,6 +156,8 @@ void TextFadeSurface::draw(std::vector<SDL_Rect>& update_rects,
   for (FadeSurfaces::iterator it = surfaces.begin();
        it != surfaces.end(); ++it, ++index) {
     SDL_Rect ch_pos = *pos;
+    ch_pos.w = (*it)->getWidth();
+    ch_pos.h = (*it)->getHeight();
     ch_pos.x += total_size * pimpl->fade_obj->getPositionPercent(index) / 100;
     (*it)->draw(update_rects, &ch_pos, area, ticks);
   }
@@ -244,29 +222,29 @@ void TextFadeSurface::setFadePercent(size_t percent) {
 
     size_t index = 0;
     for (FadeSurfaces::iterator it = surfaces.begin();
-	 it != surfaces.end(); ++it, ++index) {
+         it != surfaces.end(); ++it, ++index) {
       int ch_pos = pimpl->fade_obj->getPositionPercent(index);
       int fadeIn_pos =
-	((100 + pimpl->fade_width) * percent / 100) - pimpl->fade_width;
+        ((100 + pimpl->fade_width) * percent / 100) - pimpl->fade_width;
       int fadeOut_pos = fadeIn_pos + pimpl->fade_width;
 
       int alpha = 0;
       if (ch_pos <= fadeIn_pos) {
-	alpha = 100;
+        alpha = 100;
 
       } else if (ch_pos < fadeOut_pos) {
-	if (((fadeIn_pos <= 0) && (fadeOut_pos <= 0)) && (ch_pos < 0)) {
-	  alpha = 0;
-	} else {
-	  alpha = 100 * (fadeOut_pos - ch_pos) / pimpl->fade_width;
-	}
+        if (((fadeIn_pos <= 0) && (fadeOut_pos <= 0)) && (ch_pos < 0)) {
+          alpha = 0;
+        } else {
+          alpha = 100 * (fadeOut_pos - ch_pos) / pimpl->fade_width;
+        }
       }
 
       // ߗݒ
       if (alpha != pimpl->surfaces_alpha[index]) {
-	(*it)->setAlpha(alpha);
-	pimpl->surfaces_alpha[index] = alpha;
-	pimpl->is_changed |= true;
+        (*it)->setAlpha(alpha);
+        pimpl->surfaces_alpha[index] = alpha;
+        pimpl->is_changed |= true;
       }
     }
   }
