@@ -18,7 +18,7 @@
 namespace beego {
   class TtfResource;
   class FadeSurfacesInterface;
-
+  class TextProperty;
 
   class TextFadeSurface : public SurfaceInterface {
     TextFadeSurface(void);
@@ -29,22 +29,12 @@ namespace beego {
     const std::auto_ptr<pImpl> pimpl;
 
   public:
-    TextFadeSurface(TtfResource* font,
-		    const char* text, size_t size,
-		    Uint32 fore_color = beego::White,
-		    Uint32 back_color = beego::Black,
-		    bool transparent = false);
-    TextFadeSurface(TtfResource* font,
-		    const Uint16* text, size_t size,
-		    Uint32 fore_color = beego::White,
-		    Uint32 back_color = beego::Black,
-		    bool transparent = false);
-
+    TextFadeSurface(const TextProperty& property);
     TextFadeSurface(FadeSurfacesInterface* fade, size_t fade_width);
     ~TextFadeSurface(void);
 
     void draw(std::vector<SDL_Rect>& update_rects,
-	      const SDL_Rect* pos, const SDL_Rect* area, size_t ticks);
+              const SDL_Rect* pos, const SDL_Rect* area, size_t ticks);
     size_t getWidth(void);
     size_t getHeight(void);
     void forceSetChanged(void);
