@@ -14,11 +14,13 @@
 #include "TextInputComponent.h"
 #include "InputEvent.h"
 #include "TextSurface.h"
+#include "TextProperty.h"
 #include "ColorSurface.h"
 #include "NullSurface.h"
 #include "Component.h"
 #include "SdlUtils.h"
 #include "PlainTextConverter.h"
+#include "UtfString.h"
 
 using namespace beego;
 
@@ -44,19 +46,30 @@ struct TextInputComponent::pImpl {
   bool is_changed;
   DrawSurface text_draw_surface;
   DrawSurface back_draw_surface;
+  std::vector<Uint16> default_text;
+  bool is_erased;
 
-  pImpl(size_t w, size_t h, TtfResource* font, size_t size,
-	Uint32 foreColor, Uint32 backColor, bool transparent,
-	int xOffset, int yOffset)
-    : width(w), height(h), ttf(font), font_size(size),
-      fore_color(foreColor), back_color(backColor),
-      is_transparent(transparent),
-      back_surface(new ColorSurface(backColor, width, height)),
-      is_decided(false), position_changed(true), converter(&plain_converter),
-      x_offset(xOffset), y_offset(yOffset), is_changed(true) {
+  pImpl(size_t w, size_t h,
+        const TextProperty& property, int xOffset, int yOffset)
+    : width(w), height(h), ttf(property.font), font_size(property.size),
+      fore_color(property.fore_color), back_color(property.back_color),
+      is_transparent(property.transparent),
+      back_surface(new ColorSurface(width, height, back_color)),
+      is_decided(false), position_changed(false), converter(&plain_converter),
+      x_offset(xOffset), y_offset(yOffset), is_changed(true),
+      is_erased(false) {
 
-    set_SdlRect(&position, 0, y_offset, width, height);
+    set_SdlRect(&position, 0, 0, width, height);
     updateSurface();
+
+    if (property.text) {
+      ustrcat(default_text, property.text);
+
+    } else if (property.utext) {
+      ustrcat(default_text, property.utext);
+    }
+    // ustrcat I[ 0x0 ǉ̂ŁA菜
+    default_text.pop_back();
   }
 
   void updateSurface(void) {
@@ -64,20 +77,19 @@ struct TextInputComponent::pImpl {
 
     if (inputed_text.empty()) {
       Surface null_surface(new NullSurface);
-      // !!! {́Aswap() ̓[vOɔzuׂAʓ|Ȃ̂ŁAƂ肠...
       std::swap(text_surface, null_surface);
 
     } else {
       inputed_text.push_back('\0');
-      Surface new_surface(new TextSurface(ttf, &inputed_text[0], font_size,
-					  fore_color, back_color,
-					  is_transparent));
+      TextProperty text_property(ttf, &inputed_text[0], font_size,
+                                 fore_color, back_color, is_transparent);
+      Surface new_surface(new TextSurface(text_property));
       inputed_text.pop_back();
 
       // 쐬T[tFX\̈zA
       if ((new_surface->getWidth() + x_offset) > width) {
-	inputed_text.pop_back();
-	return;
+        inputed_text.pop_back();
+        return;
       }
       std::swap(text_surface, new_surface);
     }
@@ -93,12 +105,10 @@ struct TextInputComponent::pImpl {
 
 
 TextInputComponent::TextInputComponent(size_t width, size_t height,
-				       TtfResource* font, size_t size,
-				       Uint32 fore_color, Uint32 back_color,
-				       bool transparent,
-				       int x_offset, int y_offset)
-  : pimpl(new pImpl(width, height, font, size,
-		    fore_color, back_color, transparent, x_offset, y_offset)) {
+                                       const TextProperty& property,
+                                       int x_offset, int y_offset)
+  : pimpl(new pImpl(width, height, property, x_offset, y_offset)) {
+  setBuffer(pimpl->default_text);
 }
 
 
@@ -107,7 +117,7 @@ TextInputComponent::~TextInputComponent(void) {
 
 
 void TextInputComponent::addSurfaceList(SurfaceList& surfaces,
-					const SDL_Rect* area, size_t ticks) {
+                                        const SDL_Rect* area, size_t ticks) {
 
   // !!! ̎ɂ́ÃT[tFXo^Ă܂̂A肩
   // !!! NullSurface o^邱Ƃɂ
@@ -116,17 +126,20 @@ void TextInputComponent::addSurfaceList(SurfaceList& surfaces,
   // !!! {́ÂŃT[tFXׂAH
   // !!! \\ɑ΁Aǂł悢bȁI
 
+  // T[tFX̓o^
   SDL_Rect text_position = pimpl->position;
   text_position.x += pimpl->x_offset;
   text_position.y += pimpl->y_offset;
+  text_position.w = pimpl->text_surface->getWidth();
+  text_position.h = pimpl->text_surface->getHeight();
 
   updateDrawSurface(pimpl->text_draw_surface, pimpl->text_surface, area,
-		    text_position, pimpl->position_changed);
+                    text_position, pimpl->position_changed);
   surfaces.push_back(&pimpl->text_draw_surface);
 
-  // wiT[tFX̔zu
+  // wiT[tFX̓o^
   updateDrawSurface(pimpl->back_draw_surface, pimpl->back_surface, area,
-		    pimpl->position, pimpl->position_changed);
+                    pimpl->position, pimpl->position_changed);
   surfaces.push_back(&pimpl->back_draw_surface);
 
   pimpl->position_changed = false;
@@ -135,7 +148,7 @@ void TextInputComponent::addSurfaceList(SurfaceList& surfaces,
 
 void TextInputComponent::setPosition(const SDL_Rect* position) {
   set_SdlRect(&pimpl->position, position->x, position->y,
-	      pimpl->position.w, pimpl->position.h);
+              pimpl->position.w, pimpl->position.h);
   pimpl->position_changed = true;
 }
 
@@ -155,46 +168,58 @@ size_t TextInputComponent::getHeight(void) {
 }
 
 
-void TextInputComponent::applyInput(const InputEvent& event) {
+void TextInputComponent::applyInput(const InputEvent& event,
+                                    std::vector<SDL_Rect>& applied_rects) {
   if (pimpl->is_decided) {
     // ͊ḿA͂󂯕tȂ
     return;
   }
 
+  typedef std::vector<InputEvent::InputKey> Input;
+
   // !!! ͂ϊĂ̕\
   bool text_changed = false;
-  for (std::vector<InputEvent::InputKey>::const_iterator
-	 it = event.key_pressed.begin(); it != event.key_pressed.end(); ++it) {
+  //Input::const_iterator rit = event.key_released.begin();
+  for (Input::const_iterator it = event.key_pressed.begin();
+       it != event.key_pressed.end(); ++it) {
 
     // L[͓ʈƂ
     // !!! {́As̃L[͂K؂ɏׂ
     // !!! ... K؂ĂȂ񂾁H ςÂĂ邵񂶂Ȃ́H
 
-    if (it->sym == SDLK_RETURN) {
-      pimpl->is_decided = true;
-      pimpl->is_changed = true;
-      return;
+    if (it->pressed_) {
+      if (it->sym_ == SDLK_RETURN) {
+	pimpl->is_decided = true;
+	pimpl->is_changed = true;
+	return;
 
-    } else if (it->sym == SDLK_ESCAPE) {
-      text_changed |= pimpl->converter->escapePressed();
-      continue;
+      } else if (it->sym_ == SDLK_BACKSPACE) {
+	text_changed |= pimpl->converter->deleteBack();
+	pimpl->is_erased = true;
+	continue;
 
-    } else if (it->sym == SDLK_BACKSPACE) {
-      text_changed |= pimpl->converter->deleteBack();
-      continue;
+      } else if (it->sym_ == SDLK_DELETE) {
+	text_changed |= pimpl->converter->deleteCurrent();
+	pimpl->is_erased = true;
+	continue;
 
-    } else if (it->sym == SDLK_DELETE) {
-      text_changed |= pimpl->converter->deleteCurrent();
-      continue;
+      } else if ((it->unicode_ & 0xff00) || (! isprint(it->unicode_))) {
+	// \łȂL[͂́AƂĈȂ
+	continue;
+      }
+      // !!! J[\ړ
 
-    } else if ((it->unicode & 0xff00) || (! isprint(it->unicode))) {
-      // \łȂL[͂́AƂĈȂ
-      continue;
+      text_changed |= pimpl->converter->addChar(it->unicode_);
+
+    } else {
+      if (it->sym_ == SDLK_ESCAPE) {
+	text_changed |= pimpl->converter->escapePressed();
+	pimpl->is_erased = true;
+	continue;
+      }
     }
-    // !!! J[\ړ
-
-    text_changed |= pimpl->converter->addChar(it->unicode);
   }
+
   if (text_changed) {
     pimpl->updateSurface();
   }
@@ -202,7 +227,9 @@ void TextInputComponent::applyInput(const InputEvent& event) {
 
 
 void TextInputComponent::registerLayer(Layer* layer) {
-  // Ȃ
+  // ĕ`𑣂
+  //pimpl->text_surface->forceSetChanged();
+  //pimpl->back_surface->forceSetChanged();
 }
 
 
@@ -217,7 +244,7 @@ void TextInputComponent::releaseDecided(void) {
 
 
 void TextInputComponent::clear(void) {
-  //fprintf(stderr, "clear\n");
+
   pimpl->converter->clear();
   pimpl->updateSurface();
 
@@ -258,3 +285,10 @@ bool TextInputComponent::isChanged(void) {
   pimpl->is_changed = false;
   return ret;
 }
+
+
+bool TextInputComponent::isErased(void) {
+  bool ret = pimpl->is_erased;
+  pimpl->is_erased = false;
+  return ret;
+}
