@@ -17,7 +17,7 @@
 
 namespace beego {
   class TtfResource;
-
+  class TextProperty;
 
   class TextRubiSurface : public SurfaceInterface {
     TextRubiSurface(void);
@@ -29,15 +29,11 @@ namespace beego {
 
   public:
     TextRubiSurface(const Uint16* kana_text, size_t rubi_size,
-		    TtfResource* font, const Uint16* kanji_text,
-		    size_t size,
-		    Uint32 fore_color = beego::White,
-		    Uint32 back_color = beego::Black,
-		    bool transparent = false);
+                    const TextProperty& property);
     ~TextRubiSurface(void);
 
     void draw(std::vector<SDL_Rect>& update_rects,
-	      const SDL_Rect* pos, const SDL_Rect* area, size_t ticks);
+              const SDL_Rect* pos, const SDL_Rect* area, size_t ticks);
     size_t getWidth(void);
     size_t getHeight(void);
     void forceSetChanged(void);
@@ -46,6 +42,7 @@ namespace beego {
 
     void setFadeMode(FadeMode mode, size_t width);
     void setFadePercent(size_t percent);
+    int getDrawOffset(void);
   };
 };
 
