@@ -8,6 +8,7 @@
 */
 
 #include "TextSurface.h"
+#include "TextProperty.h"
 #include "Surface.h"
 #include "TtfResource.h"
 #include "SdlUtils.h"
@@ -20,7 +21,7 @@ struct TextSurface::pImpl {
   boost::shared_ptr<SdlSurface> surface;
 
   void initialize(TtfResource* font, const Uint16* text_data, size_t size,
-		  Uint32 fore, Uint32 back, bool transparent) {
+                  Uint32 fore, Uint32 back, bool transparent) {
 
     // T[tFX̍쐬
     SDL_Color fore_color;
@@ -29,47 +30,43 @@ struct TextSurface::pImpl {
     set_SdlColor(&back_color, back);
     boost::shared_ptr<SdlSurface>
       new_surface(new SdlSurface
-		  (TTF_RenderUNICODE_Shaded(font->getResource(size),
-					    &text_data[0],
-					    fore_color, back_color),
-		   transparent));
+                  (TTF_RenderUNICODE_Shaded(font->getResource(size),
+                                            &text_data[0],
+                                            fore_color, back_color),
+                   transparent));
     std::swap(surface, new_surface);
   }
 
-  pImpl(TtfResource* font, const char* text, size_t size,
-	Uint32 fore, Uint32 back, bool transparent) {
-    std::vector<Uint16> text_data;
-    for (int i = 0; text[i] != 0x0; ++i) {
-      text_data.push_back(text[i]);
-    }
-    text_data.push_back(0x0);
-    initialize(font, &text_data[0], size, fore, back, transparent);
-  }
+  pImpl(const TextProperty& property) {
 
-  pImpl(TtfResource* font, const Uint16* text, size_t size,
-	Uint32 fore, Uint32 back, bool transparent) {
-    initialize(font, text, size, fore, back, transparent);
+    if (property.text) {
+      // const char* 񂪓o^Ăꍇ́A
+      // Uint16 ăT[tFX𐶐
+      std::vector<Uint16> text_data;
+      for (int i = 0; property.text[i] != 0x0; ++i) {
+        text_data.push_back(property.text[i]);
+      }
+      text_data.push_back(0x0);
+
+      initialize(property.font, &text_data[0], property.size,
+                 property.fore_color, property.back_color,
+                 property.transparent);
+    } else {
+      initialize(property.font, property.utext, property.size,
+                 property.fore_color, property.back_color,
+                 property.transparent);
+    }
   }
 
   ~pImpl(void) {
     //surface.clear();
+    // !!! KvȂ񂾂H Aclear() ĉH
   }
 };
 
 
-TextSurface::TextSurface(TtfResource* font,
-			 const char* text, size_t size,
-			 Uint32 fore_color, Uint32 back_color,
-			 bool transparent)
-  : pimpl(new pImpl(font, text, size, fore_color, back_color, transparent)) {
-}
-
-
-TextSurface::TextSurface(TtfResource* font,
-			 const Uint16* text, size_t size,
-			 Uint32 fore_color, Uint32 back_color,
-			 bool transparent)
-  : pimpl(new pImpl(font, text, size, fore_color, back_color, transparent)) {
+TextSurface::TextSurface(const TextProperty& text_property)
+  : pimpl(new pImpl(text_property)) {
 }
 
 
@@ -78,8 +75,8 @@ TextSurface::~TextSurface(void) {
 
 
 void TextSurface::draw(std::vector<SDL_Rect>& update_rects,
-		       const SDL_Rect* pos, const SDL_Rect* area,
-		       size_t ticks) {
+                       const SDL_Rect* pos, const SDL_Rect* area,
+                       size_t ticks) {
   pimpl->surface->draw(update_rects, pos, area, ticks);
 }
 
