@@ -16,8 +16,7 @@
 
 namespace beego {
   class TtfResource;
-  class SdlSurface;
-
+  class TextProperty;
 
   /*!
     \brief T[tFX
@@ -30,20 +29,11 @@ namespace beego {
     const std::auto_ptr<pImpl> pimpl;
 
   public:
-    TextSurface(TtfResource* font,
-		const char* text, size_t size,
-		Uint32 fore_color = beego::White,
-		Uint32 back_color = beego::Black,
-		bool transparent = false);
-    TextSurface(TtfResource* font,
-		const Uint16* text, size_t size,
-		Uint32 fore_color = beego::White,
-		Uint32 back_color = beego::Black,
-		bool transparent = false);
+    TextSurface(const TextProperty& text_property);
     ~TextSurface(void);
 
     void draw(std::vector<SDL_Rect>& update_rects,
-	      const SDL_Rect* pos, const SDL_Rect* area, size_t ticks);
+              const SDL_Rect* pos, const SDL_Rect* area, size_t ticks);
     size_t getWidth(void);
     size_t getHeight(void);
     void forceSetChanged(void);
