@@ -8,6 +8,8 @@
   \author Satofumi KAMIMURA
 
   $Id$
+
+  \todo OpenGL łŃL[͂Ȃ̂AȂƂ
 */
 
 
@@ -19,14 +21,14 @@
 
 // o[W
 #ifndef VERSION
-#define VERSION "0.0.1"		//!< o[W
+#define VERSION "X.X.X"         //!< o[W
 #endif
 const char*const VersionText = "version " VERSION; //!< o[W
 
 
 // lbg[N
 enum {
-  ServerPort = 57577,		//!< lbg[Nΐp̐ڑ|[gԍ
+  ServerPort = 57577,          //!< lbg[Nΐp̐ڑ|[gԍ
 };
 
 #endif /* !HYAKUTYPING_H */
